summaryrefslogtreecommitdiffstats
path: root/contrib/gcc/splay-tree.c
diff options
context:
space:
mode:
Diffstat (limited to 'contrib/gcc/splay-tree.c')
-rw-r--r--contrib/gcc/splay-tree.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/contrib/gcc/splay-tree.c b/contrib/gcc/splay-tree.c
index 7999447..6f90fde 100644
--- a/contrib/gcc/splay-tree.c
+++ b/contrib/gcc/splay-tree.c
@@ -234,7 +234,7 @@ splay_tree_xmalloc_allocate (size, data)
int size;
void *data ATTRIBUTE_UNUSED;
{
- return xmalloc (size);
+ return (void *) xmalloc (size);
}
static void
@@ -482,7 +482,7 @@ splay_tree_predecessor (sp, key)
}
/* Return the immediate successor KEY, or NULL if there is no
- predecessor. KEY need not be present in the tree. */
+ successor. KEY need not be present in the tree. */
splay_tree_node
splay_tree_successor (sp, key)
@@ -492,7 +492,7 @@ splay_tree_successor (sp, key)
int comparison;
splay_tree_node node;
/* If the tree is empty, there is certainly no predecessor. */
if (!sp->root)
return NULL;
OpenPOWER on IntegriCloud
@@ -492,7 +492,7 @@ splay_tree_successor (sp, key)
int comparison;
splay_tree_node node;
- /* If the tree is empty, there is certainly no predecessor. */
+ /* If the tree is empty, there is certainly no successor. */
if (!sp->root)
return NULL;